<?php
// Register Styles
function onlook_styles() {

	wp_register_style( 'normalize', get_template_directory_uri().'/normalize.css', false, '3.0.2', 'all' );
	wp_enqueue_style( 'normalize' );
	
	wp_register_style( 'roboto-slab', '//fonts.googleapis.com/css?family=Roboto+Slab:700,400&subset=latin,latin-ext', array( 'normalize' ), '1.0', 'all' );
	wp_enqueue_style( 'roboto-slab' );

	wp_register_style( 'style', get_stylesheet_uri(), array( 'normalize', 'roboto-slab'), '1.0', 'all' );
	wp_enqueue_style( 'style' );

}
add_action( 'wp_enqueue_scripts', 'onlook_styles' );

// Register Scripts
function onlook_scripts() {

	wp_deregister_script( 'main' );
	wp_register_script( 'main', get_template_directory_uri().'/scripts/main.js', array( 'jquery', 'jquery-ui-core' ), '1.0', true );
	wp_enqueue_script( 'main' );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'onlook_scripts' );

// Register Navigation Menus
function onlook_menus() {

	$locations = array(
		'top' => __( 'Top menu', 'onlook' ),
	);
	register_nav_menus( $locations );

}
add_action( 'init', 'onlook_menus' );

// Register Sidebars
function onlook_sidebars() {

	$args = array(
		'id'            => 'sidebar_top',
		'name'          => __( 'Top Widget Area', 'onlook' ),
		'description'   => __( 'On smaller screens (width < 786px) shows at top of the page.\nConsider how many widgets you want to add.You may need to alter min-height for <main> in stylesheet', 'onlook' ),
		'before_title'  => '<h3 class="widgettitle">',
		'after_title'   => '</h3>',
	);
	register_sidebar( $args );

	$args = array(
		'id'            => 'sidebar_main',
		'name'          => __( 'Main Sidebar', 'onlook' ),
		'description'   => __( 'On smaller screens (width < 786px) shows at bottom of the page', 'onlook' ),
		'before_title'  => '<h3 class="widgettitle">',
		'after_title'   => '</h3>',
	);
	register_sidebar( $args );

}
add_action( 'widgets_init', 'onlook_sidebars' );

// Set content width value based on the theme's design
if ( ! isset( $content_width ) )
	$content_width = 1600;

if ( ! function_exists('onlook_theme_features') ) {

// Register Theme Features
function onlook_theme_features()  {

	// Add theme support for Featured Images
	add_theme_support( 'post-thumbnails' );

	 // Set custom thumbnail dimensions
	set_post_thumbnail_size( 200, 150, true );

	// Add theme support for Custom Background
	$background_args = array(
		'default-color'          => 'FEFEFE',
		'default-image'          => '',
		'default-repeat'         => 'no-repeat',
		'default-position-x'     => 'top center',
		'wp-head-callback'       => '_custom_background_cb',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	);
	add_theme_support( 'custom-background', $background_args );

	// Add theme support for Custom Header
	$header_args = array(
		'default-image'          => get_template_directory_uri() . '/images/header.png',
		'width'                  => 500,
		'height'                 => 200,
		'flex-width'             => true,
		'flex-height'            => true,
		'uploads'                => true,
		'random-default'         => false,
		'header-text'            => false,
		'default-text-color'     => '',
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	);
	add_theme_support( 'custom-header', $header_args );

	// Add theme support for HTML5 Semantic Markup
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

	// Add theme support for document Title tag
	add_theme_support( 'title-tag' );

	// Add theme support for Translation
	load_theme_textdomain( 'onlook', get_template_directory() . '/lang' );
	
	// Add theme support for Automatic Feed Links
	add_theme_support( 'automatic-feed-links' );
}
add_action( 'after_setup_theme', 'onlook_theme_features' );
}

//Customizer

function onlook_register_theme_customizer( $wp_customize ) {
	//Custom colors 
    $wp_customize->add_setting(
        'onlook_text_color',
        array(
            'default'     => '#000000',
			'sanitize_callback' => 'sanitize_hex_color',
        )
    );
	$wp_customize->add_setting(
        'onlook_link_color',
        array(
            'default'     => '#000000',
			'sanitize_callback' => 'sanitize_hex_color',
        )
    );
	$wp_customize->add_setting(
        'onlook_accent_color',
        array(
            'default'     => '#AF1F23',
			'sanitize_callback' => 'sanitize_hex_color',
        )
    );
	
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'text_color',
            array(
                'label'      => __( 'Text Color', 'onlook' ),
                'section'    => 'colors',
                'settings'   => 'onlook_text_color'
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'link_color',
            array(
                'label'      => __( 'Link Color', 'onlook' ),
                'section'    => 'colors',
                'settings'   => 'onlook_link_color'
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'accent_color',
            array(
                'label'      => _x( 'Accent Color','secondary color' ,'onlook' ),
                'section'    => 'colors',
                'settings'   => 'onlook_accent_color'
            )
        )
    );
	//Footer
	$wp_customize->add_section('onlook_footer_section' , array(
		'title'     => __('Footer', 'onlook'),
		'priority'  => 90
	));
	
	$wp_customize->add_setting('show_footer_sitemap', array(
		'default'        => 0,
		'capability'     => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw',
	));
	
	$wp_customize->add_setting('show_footer_powered_by', array(
		'default'        => 1,
		'capability'     => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw',
	));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'show_footer_sitemap',
			array(
				/* translators: 1: sitemap */
				'label'     => sprintf(_x('Show %1s','verb', 'onlook'),__( 'Sitemap','onlook')),
				'description'     => __('Links to sitemap.xml in your root directory', 'onlook'),
				'section'   => 'onlook_footer_section',
				'settings'  => 'show_footer_sitemap',
				'type'      => 'checkbox',
			)
		)
	);
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'show_powered_by',
			array(
				'label'     => sprintf(_x('Show %1s','verb', 'onlook'),__( 'Powered by WordPress','onlook')),
				'section'   => 'onlook_footer_section',
				'settings'  => 'show_footer_powered_by',
				'type'      => 'checkbox',
			)
		)
	);
}
add_action( 'customize_register', 'onlook_register_theme_customizer' );

function onlook_customizer_css() {
    ?>
    <style type="text/css">
		body { color: <?php echo get_theme_mod( 'onlook_text_color' ); ?>; }
        a { color: <?php echo get_theme_mod( 'onlook_link_color' ); ?>; }
		a:hover, a:focus { color: <?php echo get_theme_mod( 'onlook_accent_color' ); ?>; }
		.post, .widget, #footer, #header, #header nav .sub-menu, #header nav .sub-menu .sub-menu {border-color: <?php echo get_theme_mod( 'onlook_accent_color' ); ?>; }
		.footer-links div, .page-numbers {border-color: <?php echo get_theme_mod( 'onlook_text_color' ); ?>; }
		#header nav .sub-menu { background-color: #<?php echo background_color(); ?>; }
		.page-numbers {background-color: #<?php echo background_color(); ?>;}
		.btn-primary, .page-numbers.current, .page-numbers:hover, .page-numbers:focus { background-color: <?php echo get_theme_mod( 'onlook_accent_color' ); ?>; color: #<?php echo background_color(); ?>; }
    </style>
    <?php
}
add_action( 'wp_head', 'onlook_customizer_css' );

//Read More link

add_filter( 'the_content_more_link', 'modify_read_more_link' );
function modify_read_more_link() {
return '<a class="more-link" href="' . get_permalink() . '" title="'.sprintf(__( 'Continue reading %s.', 'onlook' ), get_the_title()).'">'.__('Read more &raquo;', 'onlook').'</a>';
}

//Comments
function onlook_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'article' == $args['style'] ) {
		$tag = 'article';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'article-comment';
	}
?>
	<<?php echo $tag ?> <?php comment_class( array(empty( $args['has_children'] ) ? '' : 'parent','clearfix' )) ?> id="comment-<?php comment_ID() ?>">
	<?php if ( 'article' != $args['style'] ) : ?>
	<article id="article-comment-<?php comment_ID() ?>" class="comment-body clearfix">
	<?php endif; ?>
	<?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
    <div class="comment-text">
		<span class="comment-meta"><strong><?php comment_author(); ?></strong>
        <span class="bullet"></span><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
        <?php
            /* translators: 1: date, 2: time */
            printf( __('%1$s at %2$s','onlook'), get_comment_date(),  get_comment_time() );
        ?></a>
        <?php if ( $comment->comment_approved == '0' ) : ?>
            <span class="bullet"></span><strong><em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.','onlook' ); ?></em></strong>
        <?php endif; ?></span>
        <?php comment_text(); ?>
    
        <div class="reply">
        <?php edit_comment_link( __( 'Edit','onlook' ), '',' <span class="bullet"></span> ' ); comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
	</div>
    </div>
	<?php if ( 'article' != $args['style'] ) : ?>
	</article>
	<?php endif; ?>
<?php
}
?>